#
# spec file for package words
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           words
Version:        7.1
Release:        22.2
Summary:        An English words dictionary
License:        SUSE-Public-Domain
Group:          Productivity/Office/Dictionary
Url:            http://wordlist.sourceforge.net/
Source0:        http://prdownloads.sourceforge.net/wordlist/scowl-7.1.tar.gz
Source1:        sysconfig.words
Source2:        SuSEconfig.words
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %fillup_prereq
Provides:       scowl = %{version}-%{release}
BuildArch:      noarch
BuildRequires:  sysvinit-tools

%description
This package contains an English words dictionary which will be installed as

/usr/share/dict/american and linked to /usr/share/dict/words

The symbolic link may be used by look(1) and ispell(1).

For a British or Canadian version of such a words dictionary you may install
words-british or words-canadian respectively.

%package -n words-british
Summary:        A British words dictionary
Group:          Productivity/Text/Utilities
Requires:       words

%description -n words-british
This package contains a British words dictionary which will be installed as

/usr/share/dict/british

For a description see the package words.

%package -n words-canadian
Summary:        A Canadian words dictionary
Group:          Productivity/Text/Utilities
Requires:       words

%description -n words-canadian
This package contains a Canadian words dictionary which will be installed as

/usr/share/dict/canadian

For a description see the package words.

%prep
%setup -q -n scowl-%{version}

%build
spellings="american british canadian"
LANG=POSIX
export POSIX
set +o posix
#
# Do resorting for look(1) command
#
test -d result/ || mkdir result
chmod u+x mk-list
for s in $spellings
do
    case "$s" in
    american*) LC_CTYPE=en_US.UTF-8 ;;
    british*)  LC_CTYPE=en_GB.UTF-8 ;;
    canadian*) LC_CTYPE=en_CA.UTF-8 ;;
    esac
    LC_COLLATE=$LC_CTYPE
    export LC_CTYPE LC_COLLATE
    > result/${s}.todo
    #
    # Fix sorting as the look(1) command expect sort option -f
    # and -d. also convert Latin-1 umlauts into UTF-8 based.
    #
    ./mk-list -v2 ${s} 80 | iconv -f latin1 -t utf8 > >(sort -fdu -S10M -o result/${s} ; rm result/${s}.todo)
done
#
# Wait on sorting FIFOs
#
for s in $spellings
do
    while test -e result/${s}.todo
    do
	usleep 50000
    done
    fsync result/${s}
done

%install
mkdir -p %{buildroot}%{_datadir}/dict
install -pm 0644 result/* %{buildroot}%{_datadir}/dict/
mkdir -p %{buildroot}%{_localstatedir}/lib/dict
ln -sf ../../..%{_datadir}/dict/american %{buildroot}%{_localstatedir}/lib/dict/words
ln -sf ../../../var/lib/dict/words %{buildroot}%{_datadir}/dict/words
mkdir -p %{buildroot}%{_libexecdir}/words
mkdir -p %{buildroot}%{_localstatedir}/adm/fillup-templates
install -pm 0644 %{SOURCE1} %{buildroot}%{_localstatedir}/adm/fillup-templates/
install -pm 0755 %{SOURCE2} %{buildroot}%{_libexecdir}/words/update

%post
%{fillup_only}
if test -x %{_libexecdir}/words/update ; then
    %{_libexecdir}/words/update
fi

%preun
test -L usr/share/dict/words && rm usr/share/dict/words || true

%files
%defattr(-,root,root,-)
%doc Copyright README
%dir %{_libexecdir}/words
%attr(755,root,root) %{_libexecdir}/words/update
%{_datadir}/dict/american
%ghost %{_datadir}/dict/words
%{_localstatedir}/adm/fillup-templates/sysconfig.words
%dir %{_localstatedir}/lib/dict/
%verify(not link mtime) %{_localstatedir}/lib/dict/words

%files -n words-british
%defattr(-,root,root,-)
%{_datadir}/dict/british

%files -n words-canadian
%defattr(-,root,root,-)
%{_datadir}/dict/canadian

%changelog
* Thu Sep 27 2012 aj@suse.de
- Remove reference to obsolete /etc/sysconfig/suseconfig.
* Thu Sep 13 2012 coolo@suse.com
- add explicit buildrequire on sysvinit-tools
* Sun Jul  1 2012 coolo@suse.com
- if there is no more SuSEconfig, YAST_IS_RUNNING has no meaning
* Mon Jun 18 2012 werner@suse.de
- Rename and relocate SuSEconfig.ispell
* Mon Mar 26 2012 werner@suse.de
- Fix typo in spec file (LC_CYPTE -> LC_CTYPE)
* Thu Mar  8 2012 werner@suse.de
- Fix sorting as the look(1) command expect sort option -f and -d
  also convert Latin-1 umlauts into UTF-8 based (bnc#742812)
* Thu Feb  9 2012 werner@suse.de
- Run SuSEconfig is not installed by YaST (bnc#745857)
* Mon Jul 25 2011 andrea.turrini@gmail.com
- Fixed typos in descriptions of words.spec
* Thu Jun  9 2011 asterios.dramis@gmail.com
- Update to version 7.1:
  * Updated to revision 5.1 of Varcon which corrected several errors.
  * Fixed various problems with the variant processing which corrected a few
    more errors.
  * Added several now common proper names and some other words now in common
    use.
  * Include misc/ and speller/ directory which where in SVN but left out of the
    release tarball.
  * Other minor fixes, including some fixes to the taboo word lists.
  From version 7:
  * Updated to revision 5.0 of Varcon which corrected many errors, especially
    in the British and Canadian spelling categories. Also added new spelling
    categories for the British and Canadian spelling variants and separated
    them out from the main variant_* categories.
  * Moved Moby names lists (3897male.nam 4946fema.len 21986na.mes) to 95 level
    since they contain too many errors and rare names.
  * Moved frequently class 0 from Brian Kelk's Wordlist from level 60 to 70,
    and also filter it with level 80 due to, too many misspellings.
  * Many other minor fixes.
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Changed Group: to Productivity/Office/Dictionary.
  * Simplified the %%build section since the package now provides a build
    script.
  * Minor other updates.
  * Removed %%changelog entries.
- Removed scowl-6.dif patch (fixed in new version).
- Improvements in SuSEconfig.words to support all combinations of installed
  dictionaries.
- Improvements in sysconfig.words (replaced ispell references with words).
* Thu Jul 26 2007 werner@suse.de
- Increase size which includes `ocular' (bug #294371)
* Tue Apr  3 2007 werner@suse.de
- Enable sorting by correcting a typo in keyword LC_CTYPE (#258445)
* Wed Jun 21 2006 werner@suse.de
- Remove self provide
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Aug 26 2005 ro@suse.de
- SuSEconfig.words back to 755
* Thu Mar 10 2005 werner@suse.de
- Use /var/lib/dict/ to handle ro /usr/share/dict/ and the
  symbolic link `words' to the choosen dictionary (bug #67048)
* Thu Feb 24 2005 werner@suse.de
- Add Prerequest for fillup (bug #66420)
* Wed Oct 27 2004 werner@suse.de
- Switch to new source package due license promblems with the
  old words list.  This new list also provides a British and
  Canadian version.
* Thu Feb  5 2004 kukuk@suse.de
- Revert wrong change to %%defattr from 4. Feb.
* Wed Feb  4 2004 hmacht@suse.de
- added option # norootforbuild in specfile
* Thu Jun 12 2003 kukuk@suse.de
- Cleanup specfile
* Thu Feb  7 2002 werner@suse.de
- Remove symbolic link because FHS-2.2 check can not determine
  backward symbolic links
* Thu Dec 14 2000 werner@suse.de
- Group tag
* Sun Jun 18 2000 ro@suse.de
- doc relocation
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jun  8 1999 bs@suse.de
- made package "noarch"
* Mon Feb  9 1998 werner@suse.de
- Move /usr/dict to /usr/share/dict,
  add symbolic link or compatibility
* Thu Feb  6 1997 werner@suse.de
- New packages: english word list needed by look or grep
